@@ -106,7 +106,7 @@ static void usage(const char *const app, const char *const reason, ...) {
     fprintf(stderr, "Supported options:\n"
             " --input/-i $file:     input file\n"
             " --output/-o $file:    output file\n"
-            " --demuxer $name:      force demuxer type ('ivf', 'section5' or 'annexb'; default: detect from extension)\n"
+            " --demuxer $name:      force demuxer type ('ivf', 'section5' or 'annexb'; default: detect from content)\n"
             " --muxer $name:        force muxer type ('md5', 'yuv', 'yuv4mpeg2' or 'null'; default: detect from extension)\n"
             " --quiet/-q:           disable status messages\n"
             " --frametimes $file:   dump frame times to file\n"
